@@ -11,19 +11,15 @@ class TokenLikelihood(CohereObject):
 class Generation(CohereObject):
     def __init__(self,
                  text: str,
-                 likelihood: float,
                  token_likelihoods: List[TokenLikelihood]) -> None:
         self.text = text
-        self.likelihood = likelihood
         self.token_likelihoods = token_likelihoods
 
 
 class Generations(CohereObject):
     def __init__(self,
-                 generations: List[Generation],
-                 return_likelihoods: str) -> None:
+                 generations: List[Generation]) -> None:
         self.generations = generations
-        self.return_likelihoods = return_likelihoods
         self.iterator = iter(generations)
 
     def __iter__(self) -> iter:
